==> oggcodecs_src_0.69.8924.zip: oggdsf/src/lib/codecs/cmml/libCMMLTags/C_CMMLPreamble.cpp <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh
   
   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "stdafx.h"
#include <libCMMLTags/C_CMMLPreamble.h>

C_CMMLPreamble::C_CMMLPreamble(void)
{
	mXmlVersion = L"1.0";
	mXmlEncoding = L"UTF-8";
	mXmlStandAlone = L"yes";

}

C_CMMLPreamble::~C_CMMLPreamble(void)
{
}

//Accessors
wstring C_CMMLPreamble::xmlVersion() {
	return mXmlVersion;
}
wstring C_CMMLPreamble::xmlEncoding() {
	return mXmlEncoding;
}
wstring C_CMMLPreamble::xmlStandAlone() {
	return mXmlStandAlone;
}


//Mutators
void C_CMMLPreamble::setXmlVersion(wstring inVersion) {

}
void C_CMMLPreamble::setXmlEncoding(wstring inEncoding) {

}
void C_CMMLPreamble::setXmlStandAlone(wstring inStandAlone) {
}

C_CMMLPreamble* C_CMMLPreamble::clone() {
	C_CMMLPreamble* retPreamble = new C_CMMLPreamble();
	retPreamble->mXmlEncoding = mXmlEncoding;
	retPreamble->mXmlStandAlone = mXmlStandAlone;
	retPreamble->mXmlVersion = mXmlVersion;
	return retPreamble;
}

//Others
wstring C_CMMLPreamble::toString() {
    wstring retStr;
	retStr = L"<?xml version=\"";
	retStr += mXmlVersion;
	retStr += L"\" encoding=\"";
	retStr += mXmlEncoding;
	retStr += L"\" standalone=\"";
	retStr += mXmlStandAlone;
	retStr += L"\"?>\n";
	
	//TO DO::: Make this more generalised properly
	retStr += L"<!DOCTYPE cmml SYSTEM \"cmml.dtd\">\n";

	return retStr;

}

==> oggcodecs_src_0.70.0827.zip: oggdsf/src/lib/codecs/cmml/libCMMLTags/C_CMMLPreamble.cpp <==
/*
   Copyright (C) 2003, 2004 Zentaro Kavanagh
   
   Copyright (C) 2003, 2004 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "stdafx.h"
#include <libCMMLTags/C_CMMLPreamble.h>

C_CMMLPreamble::C_CMMLPreamble(void)
{
	mXmlVersion = L"1.0";
	mXmlEncoding = L"UTF-8";
	mXmlStandAlone = L"yes";

}

C_CMMLPreamble::~C_CMMLPreamble(void)
{
}

//Accessors
wstring C_CMMLPreamble::xmlVersion() {
	return mXmlVersion;
}
wstring C_CMMLPreamble::xmlEncoding() {
	return mXmlEncoding;
}
wstring C_CMMLPreamble::xmlStandAlone() {
	return mXmlStandAlone;
}


//Mutators
void C_CMMLPreamble::setXmlVersion(wstring inVersion) {

}
void C_CMMLPreamble::setXmlEncoding(wstring inEncoding) {

}
void C_CMMLPreamble::setXmlStandAlone(wstring inStandAlone) {
}

C_CMMLPreamble* C_CMMLPreamble::clone() {
	C_CMMLPreamble* retPreamble = new C_CMMLPreamble();
	retPreamble->mXmlEncoding = mXmlEncoding;
	retPreamble->mXmlStandAlone = mXmlStandAlone;
	retPreamble->mXmlVersion = mXmlVersion;
	return retPreamble;
}

//Others
wstring C_CMMLPreamble::toString() {
    wstring retStr;
	retStr = L"<?xml version=\"";
	retStr += mXmlVersion;
	retStr += L"\" encoding=\"";
	retStr += mXmlEncoding;
	retStr += L"\" standalone=\"";
	retStr += mXmlStandAlone;
	retStr += L"\"?>\r\n";
	
	//TO DO::: Make this more generalised properly
	retStr += L"<!DOCTYPE cmml SYSTEM \"cmml.dtd\">\r\n";

	return retStr;

}
